==> aprs4r-0.9.9.1.tar.gz: aprs4r-0.9.9.1/src/aprs4r/BuddyGatewayPluginConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/ConfigurationAttribute'
require 'aprs4r/PluginConfiguration'


module APRS4R

  class GatewayPluginConfiguration < PluginConfiguration

    attr_reader :inDevice, :outDevice, :filter, :path
    attr_writer :inDevice, :outDevice, :filter, :path

    def initialize( inDevice, outDevice, filter = nil, path = [])
      @inDevice = inDevice
      @outDevice = outDevice
      @filter = filter 
      @path = path
    end

    def to_yaml_properties
      return super + %w{@inDevice @outDevice @filter}
    end

    def attributes
      
      attributes = [ 
                    ConfigurationAttribute.new( "inDevice",  "text", true, 10, "rf0", "Empfangsschnittstelle"),
                    ConfigurationAttribute.new( "outDevice", "text", true, 10, "is0", "Sendeschnittstelle"),
                    ConfigurationAttribute.new( "filter",    "array", true, 20, ["*"], "Filter"),
                    ConfigurationAttribute.new( "path",      "array", true, 20, [], "Aussendepfad")
                   ]

      return super + attributes
    end

  end

end

==> aprs4r-0.9.9.2.tar.gz: aprs4r-0.9.9.2/src/aprs4r/BuddyGatewayPluginConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/ConfigurationAttribute'
require 'aprs4r/GatewayPluginConfiguration'


module APRS4R

  class BuddyGatewayPluginConfiguration < GatewayPluginConfiguration

    attr_reader :filter, :path
    attr_writer :filter, :path


    def initialize( inDevice, outDevice, filter = nil, path = [])
      super( inDevice, outDevice)

      @filter = filter 
      @path = path

      return
    end


    def to_yaml_properties
      return super + %w{@filter @path}
    end


    def attributes
      
      attributes = [ 
                    ConfigurationAttribute.new( "filter",    "array", true, 20, ["*"], "Filter"),
                    ConfigurationAttribute.new( "path",      "array", true, 20, [], "Aussendepfad")
                   ]

      return super + attributes
    end

  end

end
